==> nys-0.7.tar.gz: nys-0.7/nsw/src/nsw/nsw_networks.h <==
/*
** nsw_networks.h         Networks cover routines for the Name Service Switch
**
** Copyright (c) 1993 Signum Support AB, Sweden
**
** This file is part of the NYS Library.
**
** The NYS Library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Library General Public License as
** published by the Free Software Foundation; either version 2 of the
** License, or (at your option) any later version.
**
** The NYS Library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.
** 
** You should have received a copy of the GNU Library General Public
** License along with the NYS Library; see the file COPYING.LIB.  If
** not, write to the Free Software Foundation, Inc., 675 Mass Ave,
** Cambridge, MA 02139, USA.
**
** Author: Peter Eriksson <pen@signum.se>
*/

#ifndef __NSSWITCH_NETWORKS_H__
#define __NSSWITCH_NETWORKS_H__

#include <sys/types.h>
#include <netdb.h>

#ifdef ENABLE_NIS
#include "../nis/nis_networks.h"
#endif

#ifdef ENABLE_YP
#include "../yp/yp_networks.h"
#endif

#ifdef ENABLE_DNS
#include "../dns/dns_networks.h"
#endif

void _ENSWF(_setnetent)(int stayopen);
void _ENSWF(_endnetent)(void);
struct netent * _ENSWF(_getnetent)(void);
struct netent * _ENSWF(_getnetbyname)(char *name);
struct netent * _ENSWF(_getnetbyaddr)(long net, int type);

#endif

==> nys-0.17.tar.gz: nys-0.17/nsw/src/nsw/nsw_networks.h <==
/*
** nsw_networks.h         Networks cover routines for the Name Service Switch
**
** Copyright (c) 1993 Signum Support AB, Sweden
**
** This file is part of the NYS Library.
**
** The NYS Library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Library General Public License as
** published by the Free Software Foundation; either version 2 of the
** License, or (at your option) any later version.
**
** The NYS Library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.
** 
** You should have received a copy of the GNU Library General Public
** License along with the NYS Library; see the file COPYING.LIB.  If
** not, write to the Free Software Foundation, Inc., 675 Mass Ave,
** Cambridge, MA 02139, USA.
**
** Author: Peter Eriksson <pen@signum.se>
*/

#ifndef __NSSWITCH_NETWORKS_H__
#define __NSSWITCH_NETWORKS_H__

#include <sys/types.h>
#include <netdb.h>

#ifdef ENABLE_NIS
#include "../nis/nis_networks.h"
#endif

#ifdef ENABLE_YP
#include "../yp/yp_networks.h"
#endif

#ifdef ENABLE_DNS
#include "../dns/dns_networks.h"
#endif

void _ENSWF(_setnetent)(int stayopen);
void _ENSWF(_endnetent)(void);
struct netent * _ENSWF(_getnetent)(void);
struct netent * _ENSWF(_getnetbyname)(const char *name);
struct netent * _ENSWF(_getnetbyaddr)(long net, int type);

#endif
